<?php

namespace Drupal\delete_files\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\delete_files\Utils;

class DeleteFiles extends FormBase {

  public function getFormId() {
    return 'delete_files_page_delete_files';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['files'] = [
      '#type' => 'tableselect',
      '#title' => 'Files',
      '#header' => array(
        'file_name' => t('File Name'),
      ),
      '#multiple' => TRUE,
      '#js_select' => FALSE,
    ];
    
    $form['actions'] = [
      '#type' => 'actions',
      '#weight' => -99,
    ];

    if(Utils::currentUser()->hasPermission('delete files')){
      $form['actions']['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Delete selected files'),
      ];

      $form['description'] = [
        '#type' => 'item',
        '#markup' => $this->t('<p>Files managed by Drupal in the file_managed table and on the Files tab are replaced by a blank file when they\'re deleted.</p>'),
        '#weight' => -98,
      ];
    } else {
      $form['description'] = [
        '#type' => 'item',
        '#markup' => $this->t('<p>Additional permissions required to delete files.</p>'),
        '#weight' => -98,
      ];
    }

    // for future development
    $showHiddenFiles = TRUE;

    $public_dir = \Drupal::service('file_system')->realpath(file_default_scheme() . "://");
    $files_arr = Utils::dirContents($public_dir, $showHiddenFiles);
    $site_URL = Utils::siteURL(); 

    foreach($files_arr as $obj){
      if(is_writable($obj['path'])){
        if($obj['have_link']){
          $form['files']['#options'][$obj['path']]['file_name']['data'] = [
            '#type' => 'item',
            '#markup' => '<a href="' . $site_URL . Utils::siteRelativePath($obj['path']) . '">' . basename($obj['path']) . '</a>',
          ];
        } else {
          $form['files']['#options'][$obj['path']]['file_name']['data'] = [
            '#type' => 'item',
            '#markup' => Utils::siteRelativePath($obj['path']),
          ];
        }
      }
    }
    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    if(Utils::currentUser()->hasPermission('delete files')){
      $results = $form_state->getValues()['files'];
      $public_dir = \Drupal::service('file_system')->realpath(file_default_scheme() . "://");
      $messenger = \Drupal::messenger();
      foreach($results as $val){
        if($val){
          file_unmanaged_delete($val);
          if(Utils::managedFile('public://' . trim(Utils::relativePath($public_dir, $val), './'))){
            touch($val);
            $messenger->addMessage($this->t('Blanked: ') . Utils::siteRelativePath($val));
          } else {
            $messenger->addMessage($this->t('Deleted: ') . Utils::siteRelativePath($val));
          }
        }
      }
    }
  }
}
