<?php

namespace Drupal\delete_files;

class Utils {
  public static function containsString($file_path, $string){
    $handle = fopen($file_path, 'r');
    while (($buffer = fgets($handle)) !== false) {
      if (strpos($buffer, $string) !== false) {
        fclose($handle);
        return TRUE;
      }   
    }
    fclose($handle);
    return FALSE;
  }

  public static function currentUser(){
    return \Drupal\user\Entity\User::load(\Drupal::currentUser()->id());
  }

  public static function dirContents($dir, $showHiddenFiles, &$results = array()){
    $files = scandir($dir);
    $see_files = TRUE;
    $have_link = TRUE;

    foreach($files as $value){
      if(basename($value) == '.htaccess' && Utils::containsString($value, 'Require all denied')){
        if(!$showHiddenFiles){
          $see_files = FALSE;
        }
        $have_link = FALSE;
        break;
      }
    }
    
    foreach($files as $value){
        $path = realpath($dir.DIRECTORY_SEPARATOR.$value);
        if(!is_dir($path) && $see_files) {
            $results[] = [ 'path' => $path, 'have_link' => $have_link ];
        }else if($value != "." && $value != "..") {
          Utils::dirContents($path, $showHiddenFiles, $results);
        }
    }
    return $results;
  }

  public static function managedFile($uri) {
    $fid = \Drupal::entityTypeManager()
      ->getStorage('file')
      ->getQuery()
      ->condition('uri', $uri)
      ->execute();
    if (!empty($fid)) {
      return TRUE;
    }
    return FALSE;
  }

  public static function relativePath($from, $to){
      $from = is_dir($from) ? rtrim($from, '\/') . '/' : $from;
      $to   = is_dir($to)   ? rtrim($to, '\/') . '/'   : $to;
      $from = str_replace('\\', '/', $from);
      $to   = str_replace('\\', '/', $to);

      $from     = explode('/', $from);
      $to       = explode('/', $to);
      $relPath  = $to;

      foreach($from as $depth => $dir) {
          if($dir === $to[$depth]) {
              array_shift($relPath);
          } else {
              $remaining = count($from) - $depth;
              if($remaining > 1) {
                  $padLength = (count($relPath) + $remaining - 1) * -1;
                  $relPath = array_pad($relPath, $padLength, '..');
                  break;
              } else {
                  $relPath[0] = './' . $relPath[0];
              }
          }
      }
      return implode('/', $relPath);
  }

  public static function siteRelativePath($path){
    $doc_root = $_SERVER["DOCUMENT_ROOT"];
    return trim(Utils::relativePath($doc_root, $path), './');
  }

  public static function siteURL(){
    $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
    $domainName = $_SERVER['HTTP_HOST'].'/';
    return $protocol.$domainName;
  }
}
